Change Log — OppiaMobile 0.4.2 documentation

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »

# Change Log

## v0.4.2 - released: 2-Jul-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/174 - Error in course API call

## v0.4.1 - released: 27-May-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/150 - add optional job title and organisation to profile
- Reset password facility https://github.com/DigitalCampus/django-oppia/issues/168
- Fix https://github.com/DigitalCampus/django-oppia/issues/173
- Fix https://github.com/DigitalCampus/django-oppia/issues/171

## v0.4.0 - released: 1-Apr-2014

- Moved to using BootStrap for design
- https://github.com/DigitalCampus/django-oppia/issues/119 - using gravatars now optional

## Previous Versions

- Change Log for v0.3.x
  - v0.3.0 - released: 30 Mar 2014
- Change Log for v0.2.x
  - v0.2.15 - 21-Mar-2014
  - v0.2.14 - 20-Mar-2014
  - v0.2.12/13 - 18-Mar-2014
  - v0.2.10/11 - 17-Mar-2014
  - v0.2.8/9 - 17-Mar-2014
  - v0.2.7 - 14-Mar-2014
  - v0.2.6 - 8-Mar-2014
  - v0.2.5 - 4-Mar-2014
  - v0.2.1
  - v0.2.0
- Change Log for v0.1.x
  - v0.1.40
  - v0.1.39
  - v0.1.38
  - v0.1.37
  - v0.1.35
  - v0.1.34
  - v0.1.33
  - v0.1.32
  - v0.1.31
  - v0.1.30
  - v0.1.29
  - v0.1.28
  - v0.1.26
  - v0.1.23
  - v0.1.22
  - v0.1.21
  - v0.1.20
  - v0.1.19
  - v0.1.18
  - v0.1.17
  - v0.1.16
  - v0.1.15
  - v0.1.14
  - v0.1.13
  - v0.1.12

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »